@@ -64,7 +64,10 @@ class VIKOR(MCDA):
         Si = 0
         for i in range(n_rows): 
             for j in range(n_cols-1): 
-                Si = self.weights[j] * (  (self.x_best[j] - float(self.df_original.iloc[i, j+1]))  / (self.x_best[j] - self.x_worst[j]) )    
+                if (self.x_best[j] - self.x_worst[j]) == 0: # prevent div by zero
+                    Si = 0
+                else:
+                    Si = self.weights[j] * (  (self.x_best[j] - float(self.df_original.iloc[i, j+1]))  / (self.x_best[j] - self.x_worst[j]) )    
                 self.df_Si_Ri.iloc[i, j+1] = Si
         
         self.df_Si_Ri["Si"] = self.df_Si_Ri.sum(axis=1) 
